@@ -28,4 +28,19 @@ Shindo.tests('bin') do
     tests('$?.exitstatus').returns(0) { $?.exitstatus }
   end
 
-end
\ No newline at end of file
+  tests('error') do
+    @output = bin(path('error'))
+    includes('ok + returns true')                   { @output }
+    includes('1 errored and 1 succeeded')           { @output }
+
+    tests('$?.exitstatus').returns(1) { $?.exitstatus }
+  end
+
+  tests('contained-error') do
+    @output = bin(path('contained-error'))
+    includes('ok + returns true')                   { @output }
+    includes('1 failed, 1 errored and 1 succeeded') { @output }
+
+    tests('$?.exitstatus').returns(1) { $?.exitstatus }
+  end
+end
