@@ -1,9 +1,10 @@
 require File.expand_path(File.join(File.dirname(__FILE__), '..', 'lib', 'shindo'))
+require 'open3'
 
 BIN = File.join(File.dirname(__FILE__), '..', 'bin', 'shindo')
 
 def bin(arguments)
-  `RUBYOPT="-rubygems" #{BIN} #{arguments}`
+  `RUBYOPT="-rrubygems" #{BIN} #{arguments}`
 end
 
 def path(name)
